@@ -1,5 +1,5 @@
 /* virt-inspector
- * Copyright (C) 2010-2012 Red Hat Inc.
+ * Copyright (C) 2010-2023 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -294,6 +294,9 @@ main (int argc, char *argv[])
    */
   add_drives (drvs);
 
+  if (key_store_requires_network (ks) && guestfs_set_network (g, 1) == -1)
+    exit (EXIT_FAILURE);
+
   if (guestfs_launch (g) == -1)
     exit (EXIT_FAILURE);
 
@@ -444,6 +447,14 @@ output_root (xmlTextWriterPtr xo, char *root)
       single_element ("hostname", str);
     free (str);
 
+#ifdef GUESTFS_HAVE_INSPECT_GET_BUILD_ID
+    str = guestfs_inspect_get_build_id (g, root);
+    if (!str) exit (EXIT_FAILURE);
+    if (STRNEQ (str, "unknown"))
+      single_element ("build_id", str);
+    free (str);
+#endif
+
     str = guestfs_inspect_get_osinfo (g, root);
     if (!str) exit (EXIT_FAILURE);
     if (STRNEQ (str, "unknown"))
